@@ -16,19 +16,14 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with astroid. If not, see <http://www.gnu.org/licenses/>.
 """astroid packaging information"""
-import sys
-
 distname = 'astroid'
 
 modname = 'astroid'
 
-numversion = (1, 4, 0)
+numversion = (1, 4, 1)
 version = '.'.join([str(num) for num in numversion])
 
-if sys.version_info >= (3, 4):
-    install_requires = ['lazy_object_proxy', 'six', 'wrapt']
-else:
-    install_requires = ['lazy_object_proxy', 'singledispatch', 'six', 'wrapt']
+install_requires = ['six', 'lazy_object_proxy', 'wrapt']
 
 license = 'LGPL'
 
